translate.convert.po2txt

Package translate :: Package convert :: Module po2txt |
[hide private]
[frames] | no frames]

# Module po2txt

source code

convert Gettext PO localization files to plain text (.txt) files

see: http://translate.sourceforge.net/wiki/toolkit/po2txt for examples and usage instructions

Classes | [hide private]
| po2txt po2txt can take a po file and generate txt.

Functions | [hide private]
converttxt(inputfile, outputfile, templatefile, wrap=None, includefuzzy=False, encoding=`'``utf-8``'`) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Variables | [hide private]
| __package__ = ``'``translate.convert``'``

Imports: textwrap, factory